From c09cf434921bd0df7e457a50270e88ba2a7da6d5 Mon Sep 17 00:00:00 2001
From: Michele Calgaro <michele.calgaro@yahoo.it>
Date: Wed, 4 Mar 2026 11:15:12 +0900
Subject: Rename KWinModule to TWinModule. This is an API/ABI change.

Signed-off-by: Michele Calgaro <michele.calgaro@yahoo.it>
---
 tdecore/tdestartupinfo.cpp          |  10 +--
 tdecore/tdestartupinfo.h            |   4 +-
 tdecore/twinmodule.cpp              | 130 ++++++++++++++++++------------------
 tdecore/twinmodule.h                |  72 ++++++++++----------
 tdehtml/ecma/kjs_window.cpp         |   2 +-
 tdehtml/java/kjavaappletwidget.cpp  |   2 +-
 tdehtml/java/kjavaappletwidget.h    |   2 +-
 tdeui/kdetrayproxy/kdetrayproxy.cpp |   2 +-
 tdeui/kdetrayproxy/kdetrayproxy.h   |   2 +-
 tdeui/kpassivepopup.h               |   2 +-
 tdeui/krootpixmap.cpp               |   4 +-
 tdeui/ksystemtray.cpp               |   2 +-
 tdeui/twindowlistmenu.cpp           |   2 +-
 tdeui/twindowlistmenu.h             |   4 +-
 14 files changed, 121 insertions(+), 119 deletions(-)

diff --git a/tdecore/twinmodule.cpp b/tdecore/twinmodule.cpp
index e34a012fd..8a0cfdded 100644
--- a/tdecore/twinmodule.cpp
+++ b/tdecore/twinmodule.cpp
@@ -1,7 +1,7 @@
 /*
     $Id$
 
-    This file is part of the KDE libraries
+    This file is part of the TDE libraries
     Copyright (C) 1999 Matthias Ettrich (ettrich@kde.org)
 
 
@@ -34,12 +34,12 @@
 #include <dcopclient.h>
 #include "netwm.h"
 
-static KWinModulePrivate* static_d = 0;
+static TWinModulePrivate* static_d = 0;
 
 static unsigned long windows_properties[ 2 ] = { NET::ClientList | NET::ClientListStacking |
 				     NET::NumberOfDesktops |
 				     NET::DesktopGeometry |
-                                     NET::DesktopViewport |
+				     NET::DesktopViewport |
 				     NET::CurrentDesktop |
 				     NET::DesktopNames |
 				     NET::ActiveWindow |
@@ -50,24 +50,24 @@ static unsigned long windows_properties[ 2 ] = { NET::ClientList | NET::ClientLi
 static unsigned long desktop_properties[ 2 ] = { 
 				     NET::NumberOfDesktops |
 				     NET::DesktopGeometry |
-                                     NET::DesktopViewport |
+				     NET::DesktopViewport |
 				     NET::CurrentDesktop |
 				     NET::DesktopNames |
 				     NET::ActiveWindow |
 				     NET::WorkArea |
 				     NET::KDESystemTrayWindows,
-                                     NET::WM2ShowingDesktop };
+				     NET::WM2ShowingDesktop };
 
-class KWinModulePrivate : public TQWidget, public NETRootInfo4
+class TWinModulePrivate : public TQWidget, public NETRootInfo4
 {
 public:
-    KWinModulePrivate(int _what)
-	: TQWidget(0,0), NETRootInfo4( tqt_xdisplay(),
-                                     _what >= KWinModule::INFO_WINDOWS ?
-                                     windows_properties : desktop_properties,
-                                     2,
-				     -1, false
-				     ),
+    TWinModulePrivate(int _what)
+        : TQWidget(0,0), NETRootInfo4( tqt_xdisplay(),
+          _what >= TWinModule::INFO_WINDOWS ?
+          windows_properties : desktop_properties,
+          2,
+          -1, false
+          ),
           strutSignalConnected( false ),
           what( _what )
     {
@@ -76,10 +76,10 @@ public:
         activate();
 	updateStackingOrder();
     }
-    ~KWinModulePrivate()
+    ~TWinModulePrivate()
     {
     }
-    TQPtrList<KWinModule> modules;
+    TQPtrList<TWinModule> modules;
 
     TQValueList<WId> windows;
     TQValueList<WId> stackingOrder;
@@ -113,19 +113,19 @@ public:
     TQPoint currentViewport(int desktop) const;
 };
 
-KWinModule::KWinModule( TQObject* parent )
+TWinModule::TWinModule( TQObject* parent )
     : TQObject( parent, "twin_module" )
 {
     init(INFO_ALL);
 }
 
-KWinModule::KWinModule( TQObject* parent, int what )
+TWinModule::TWinModule( TQObject* parent, int what )
     : TQObject( parent, "twin_module" )
 {
     init(what);
 }
 
-void KWinModule::init(int what)
+void TWinModule::init(int what)
 {
     if (what >= INFO_WINDOWS)
        what = INFO_WINDOWS;
@@ -134,15 +134,15 @@ void KWinModule::init(int what)
 
     if ( !static_d )
     {
-        static_d = new KWinModulePrivate(what);
+        static_d = new TWinModulePrivate(what);
     }
     else if (static_d->what < what)
     {
-        TQPtrList<KWinModule> modules = static_d->modules;
+        TQPtrList<TWinModule> modules = static_d->modules;
         delete static_d;
-        static_d = new KWinModulePrivate(what);
+        static_d = new TWinModulePrivate(what);
         static_d->modules = modules;
-        for ( TQPtrListIterator<KWinModule> mit( modules ); mit.current(); ++mit )
+        for ( TQPtrListIterator<TWinModule> mit( modules ); mit.current(); ++mit )
             (*mit)->d = static_d;
     }
     
@@ -150,7 +150,7 @@ void KWinModule::init(int what)
     d->modules.append( this );
 }
 
-KWinModule::~KWinModule()
+TWinModule::~TWinModule()
 {
     d->modules.removeRef( this );
     if ( d->modules.isEmpty() ) {
@@ -159,28 +159,28 @@ KWinModule::~KWinModule()
     }
 }
 
-const TQValueList<WId>& KWinModule::windows() const
+const TQValueList<WId>& TWinModule::windows() const
 {
     return d->windows;
 }
 
-const TQValueList<WId>& KWinModule::stackingOrder() const
+const TQValueList<WId>& TWinModule::stackingOrder() const
 {
     return d->stackingOrder;
 }
 
 
-bool KWinModule::hasWId(WId w) const
+bool TWinModule::hasWId(WId w) const
 {
     return d->windows.findIndex( w ) != -1;
 }
 
-const TQValueList<WId>& KWinModule::systemTrayWindows() const
+const TQValueList<WId>& TWinModule::systemTrayWindows() const
 {
     return d->systemTrayWindows;
 }
 
-TQSize KWinModulePrivate::numberOfViewports(int desktop) const
+TQSize TWinModulePrivate::numberOfViewports(int desktop) const
 {
     NETSize netdesktop = desktopGeometry(desktop);
     TQSize s(netdesktop.width / TQApplication::desktop()->width(),
@@ -192,7 +192,7 @@ TQSize KWinModulePrivate::numberOfViewports(int desktop) const
     return s;
 }
 
-TQPoint KWinModulePrivate::currentViewport(int desktop) const
+TQPoint TWinModulePrivate::currentViewport(int desktop) const
 {
     NETPoint netviewport = desktopViewport(desktop);
 
@@ -200,7 +200,7 @@ TQPoint KWinModulePrivate::currentViewport(int desktop) const
             1+(netviewport.y / TQApplication::desktop()->height()));
 }
 
-bool KWinModulePrivate::x11Event( XEvent * ev )
+bool TWinModulePrivate::x11Event( XEvent * ev )
 {
     if ( ev->xany.window == tqt_xrootwin() ) {
         int old_current_desktop = currentDesktop();
@@ -211,36 +211,36 @@ bool KWinModulePrivate::x11Event( XEvent * ev )
 	NETRootInfo::event( ev, m, 5 );
 
 	if (( m[ PROTOCOLS ] & CurrentDesktop ) && currentDesktop() != old_current_desktop )
-	    for ( TQPtrListIterator<KWinModule> mit( modules ); mit.current(); ++mit )
+	    for ( TQPtrListIterator<TWinModule> mit( modules ); mit.current(); ++mit )
 		emit (*mit)->currentDesktopChanged( currentDesktop() );
 	if (( m[ PROTOCOLS ] & ActiveWindow ) && activeWindow() != old_active_window )
-	    for ( TQPtrListIterator<KWinModule> mit( modules ); mit.current(); ++mit )
+	    for ( TQPtrListIterator<TWinModule> mit( modules ); mit.current(); ++mit )
 		emit (*mit)->activeWindowChanged( activeWindow() );
 	if ( m[ PROTOCOLS ] & DesktopViewport ) {
-	    for ( TQPtrListIterator<KWinModule> mit( modules ); mit.current(); ++mit )
+	    for ( TQPtrListIterator<TWinModule> mit( modules ); mit.current(); ++mit )
 		emit (*mit)->currentDesktopViewportChanged(currentDesktop(),
                         currentViewport(currentDesktop()));
         }
 	if ( m[ PROTOCOLS ] & DesktopGeometry ) {
-	    for ( TQPtrListIterator<KWinModule> mit( modules ); mit.current(); ++mit )
+	    for ( TQPtrListIterator<TWinModule> mit( modules ); mit.current(); ++mit )
 		emit (*mit)->desktopGeometryChanged(currentDesktop());
 	}
 	if ( m[ PROTOCOLS ] & DesktopNames )
-	    for ( TQPtrListIterator<KWinModule> mit( modules ); mit.current(); ++mit )
+	    for ( TQPtrListIterator<TWinModule> mit( modules ); mit.current(); ++mit )
 		emit (*mit)->desktopNamesChanged();
 	if (( m[ PROTOCOLS ] & NumberOfDesktops ) && numberOfDesktops() != old_number_of_desktops )
-	    for ( TQPtrListIterator<KWinModule> mit( modules ); mit.current(); ++mit )
+	    for ( TQPtrListIterator<TWinModule> mit( modules ); mit.current(); ++mit )
 		emit (*mit)->numberOfDesktopsChanged( numberOfDesktops() );
 	if ( m[ PROTOCOLS ] & WorkArea )
-	    for ( TQPtrListIterator<KWinModule> mit( modules ); mit.current(); ++mit )
+	    for ( TQPtrListIterator<TWinModule> mit( modules ); mit.current(); ++mit )
 		emit (*mit)->workAreaChanged();
 	if ( m[ PROTOCOLS ] & ClientListStacking ) {
 	    updateStackingOrder();
-	    for ( TQPtrListIterator<KWinModule> mit( modules ); mit.current(); ++mit )
+	    for ( TQPtrListIterator<TWinModule> mit( modules ); mit.current(); ++mit )
 		emit (*mit)->stackingOrderChanged();
 	}
         if(( m[ PROTOCOLS2 ] & WM2ShowingDesktop ) && showingDesktop() != old_showing_desktop ) {
-	    for ( TQPtrListIterator<KWinModule> mit( modules ); mit.current(); ++mit )
+	    for ( TQPtrListIterator<TWinModule> mit( modules ); mit.current(); ++mit )
 		emit (*mit)->showingDesktopChanged( showingDesktop());
         }
     } else  if ( windows.findIndex( ev->xany.window ) != -1 ){
@@ -261,7 +261,7 @@ bool KWinModulePrivate::x11Event( XEvent * ev )
         	possibleStrutWindows.append( ev->xany.window );
 	}
 	if ( dirty[ NETWinInfo::PROTOCOLS ] || dirty[ NETWinInfo::PROTOCOLS2 ] ) {
-	    for ( TQPtrListIterator<KWinModule> mit( modules ); mit.current(); ++mit ) {
+	    for ( TQPtrListIterator<TWinModule> mit( modules ); mit.current(); ++mit ) {
 		emit (*mit)->windowChanged( ev->xany.window );
                 emit (*mit)->windowChanged( ev->xany.window, dirty );
 		emit (*mit)->windowChanged( ev->xany.window, dirty[ NETWinInfo::PROTOCOLS ] );
@@ -274,7 +274,7 @@ bool KWinModulePrivate::x11Event( XEvent * ev )
     return false;
 }
 
-bool KWinModulePrivate::removeStrutWindow( WId w )
+bool TWinModulePrivate::removeStrutWindow( WId w )
 {
     for( TQValueList< StrutData >::Iterator it = strutWindows.begin();
          it != strutWindows.end();
@@ -286,16 +286,16 @@ bool KWinModulePrivate::removeStrutWindow( WId w )
     return false;
 }
 
-void KWinModulePrivate::updateStackingOrder()
+void TWinModulePrivate::updateStackingOrder()
 {
     stackingOrder.clear();
     for ( int i = 0; i <  clientListStackingCount(); i++ )
 	stackingOrder.append( clientListStacking()[i] );
 }
 
-void KWinModulePrivate::addClient(Window w)
+void TWinModulePrivate::addClient(Window w)
 {
-    if ( (what >= KWinModule::INFO_WINDOWS) && !TQWidget::find( w ) )
+    if ( (what >= TWinModule::INFO_WINDOWS) && !TQWidget::find( w ) )
 	XSelectInput( tqt_xdisplay(), w, PropertyChangeMask | StructureNotifyMask );
     bool emit_strutChanged = false;
     if( strutSignalConnected && modules.count() > 0 ) {
@@ -308,14 +308,14 @@ void KWinModulePrivate::addClient(Window w)
     } else
         possibleStrutWindows.append( w );
     windows.append( w );
-    for ( TQPtrListIterator<KWinModule> mit( modules ); mit.current(); ++mit ) {
+    for ( TQPtrListIterator<TWinModule> mit( modules ); mit.current(); ++mit ) {
 	emit (*mit)->windowAdded( w );
 	if ( emit_strutChanged )
 	    emit (*mit)->strutChanged();
     }
 }
 
-void KWinModulePrivate::removeClient(Window w)
+void TWinModulePrivate::removeClient(Window w)
 {
     bool emit_strutChanged = removeStrutWindow( w );
     if( strutSignalConnected && possibleStrutWindows.findIndex( w ) != -1 && modules.count() > 0 ) {
@@ -327,58 +327,58 @@ void KWinModulePrivate::removeClient(Window w)
     }
     possibleStrutWindows.remove( w );
     windows.remove( w );
-    for ( TQPtrListIterator<KWinModule> mit( modules ); mit.current(); ++mit ) {
+    for ( TQPtrListIterator<TWinModule> mit( modules ); mit.current(); ++mit ) {
 	emit (*mit)->windowRemoved( w );
 	if ( emit_strutChanged )
 	    emit (*mit)->strutChanged();
     }
 }
 
-void KWinModulePrivate::addSystemTrayWin(Window w)
+void TWinModulePrivate::addSystemTrayWin(Window w)
 {
     systemTrayWindows.append( w );
-    for ( TQPtrListIterator<KWinModule> mit( modules ); mit.current(); ++mit )
+    for ( TQPtrListIterator<TWinModule> mit( modules ); mit.current(); ++mit )
 	emit (*mit)->systemTrayWindowAdded( w );
 }
 
-void KWinModulePrivate::removeSystemTrayWin(Window w)
+void TWinModulePrivate::removeSystemTrayWin(Window w)
 {
     systemTrayWindows.remove( w );
-    for ( TQPtrListIterator<KWinModule> mit( modules ); mit.current(); ++mit )
+    for ( TQPtrListIterator<TWinModule> mit( modules ); mit.current(); ++mit )
 	emit (*mit)->systemTrayWindowRemoved( w );
 }
 
-int KWinModule::currentDesktop() const
+int TWinModule::currentDesktop() const
 {
     return d->currentDesktop();
 }
 
-int KWinModule::numberOfDesktops() const
+int TWinModule::numberOfDesktops() const
 {
     return d->numberOfDesktops();
 }
 
-TQSize KWinModule::numberOfViewports(int desktop) const
+TQSize TWinModule::numberOfViewports(int desktop) const
 {
     return d->numberOfViewports(desktop);
 }
 
-TQPoint KWinModule::currentViewport(int desktop) const
+TQPoint TWinModule::currentViewport(int desktop) const
 {
     return d->currentViewport(desktop);
 }
 
-WId KWinModule::activeWindow() const
+WId TWinModule::activeWindow() const
 {
     return d->activeWindow();
 }
 
-bool KWinModule::showingDesktop() const
+bool TWinModule::showingDesktop() const
 {
     return d->showingDesktop();
 }
 
-TQRect KWinModule::workArea( int desktop ) const
+TQRect TWinModule::workArea( int desktop ) const
 {
     int desk  = (desktop > 0 && desktop <= (int) d->numberOfDesktops() ) ? desktop : currentDesktop();
     if ( desk <= 0 )
@@ -389,7 +389,7 @@ TQRect KWinModule::workArea( int desktop ) const
     return TQRect( r.pos.x, r.pos.y, r.size.width, r.size.height );
 }
 
-TQRect KWinModule::workArea( const TQValueList<WId>& exclude, int desktop ) const
+TQRect TWinModule::workArea( const TQValueList<WId>& exclude, int desktop ) const
 {
     TQRect all = TQApplication::desktop()->geometry();
     TQRect a = all;
@@ -406,7 +406,7 @@ TQRect KWinModule::workArea( const TQValueList<WId>& exclude, int desktop ) cons
 // to repeatedly find out struts of all windows. Therefore strut values for strut
 // windows are cached here.
         NETStrut strut;
-        TQValueList< KWinModulePrivate::StrutData >::Iterator it2 = d->strutWindows.begin();
+        TQValueList< TWinModulePrivate::StrutData >::Iterator it2 = d->strutWindows.begin();
         for( ;
              it2 != d->strutWindows.end();
              ++it2 )
@@ -420,7 +420,7 @@ TQRect KWinModule::workArea( const TQValueList<WId>& exclude, int desktop ) cons
             NETWinInfo info( tqt_xdisplay(), (*it1), tqt_xrootwin(), NET::WMStrut | NET::WMDesktop);
 	    strut = info.strut();
             d->possibleStrutWindows.remove( *it1 );
-            d->strutWindows.append( KWinModulePrivate::StrutData( *it1, info.strut(), info.desktop()));
+            d->strutWindows.append( TWinModulePrivate::StrutData( *it1, info.strut(), info.desktop()));
 	    if(!(info.desktop() == desktop || info.desktop() == NETWinInfo::OnAllDesktops))
                 continue;
         } else
@@ -443,14 +443,14 @@ TQRect KWinModule::workArea( const TQValueList<WId>& exclude, int desktop ) cons
     return a;
 }
 
-void KWinModule::connectNotify( const char* signal )
+void TWinModule::connectNotify( const char* signal )
 {
     if( !d->strutSignalConnected && qstrcmp( signal, TQ_SIGNAL(strutChanged())) == 0 )
         d->strutSignalConnected = true;
     TQObject::connectNotify( signal );
 }
 
-TQString KWinModule::desktopName( int desktop ) const
+TQString TWinModule::desktopName( int desktop ) const
 {
     const char* name = d->desktopName( (desktop > 0 && desktop <= (int) d->numberOfDesktops() ) ? desktop : currentDesktop() );
     if ( name && name[0] )
@@ -458,7 +458,7 @@ TQString KWinModule::desktopName( int desktop ) const
     return i18n("Desktop %1").arg( desktop );
 }
 
-void KWinModule::setDesktopName( int desktop, const TQString& name )
+void TWinModule::setDesktopName( int desktop, const TQString& name )
 {
     if (desktop <= 0 || desktop > (int) d->numberOfDesktops() )
 	desktop = currentDesktop();
@@ -466,7 +466,7 @@ void KWinModule::setDesktopName( int desktop, const TQString& name )
 }
 
 
-void KWinModule::doNotManage( const TQString& title )
+void TWinModule::doNotManage( const TQString& title )
 {
     if ( !tdeApp->dcopClient()->isAttached() )
 	tdeApp->dcopClient()->attach();
diff --git a/tdehtml/ecma/kjs_window.cpp b/tdehtml/ecma/kjs_window.cpp
index 96d703833..cd35624f6 100644
--- a/tdehtml/ecma/kjs_window.cpp
+++ b/tdehtml/ecma/kjs_window.cpp
@@ -161,7 +161,7 @@ Value Screen::get(ExecState *exec, const Identifier &p) const
 Value Screen::getValueProperty(ExecState *exec, int token) const
 {
 #if defined TQ_WS_X11 && ! defined K_WS_QTONLY
-  KWinModule info(0, KWinModule::INFO_DESKTOP);
+  TWinModule info(0, TWinModule::INFO_DESKTOP);
 #endif
   TQWidget *thisWidget = Window::retrieveActive(exec)->part()->widget();
   TQRect sg = TDEGlobalSettings::desktopGeometry(thisWidget);
diff --git a/tdehtml/java/kjavaappletwidget.cpp b/tdehtml/java/kjavaappletwidget.cpp
index 83485019c..71fcf05e7 100644
--- a/tdehtml/java/kjavaappletwidget.cpp
+++ b/tdehtml/java/kjavaappletwidget.cpp
@@ -46,7 +46,7 @@ KJavaAppletWidget::KJavaAppletWidget( TQWidget* parent, const char* name )
 
     m_applet = new KJavaApplet( this );
     d        = new KJavaAppletWidgetPrivate;
-    m_kwm    = new KWinModule( this );
+    m_kwm    = new TWinModule( this );
 
     d->tmplabel = new TQLabel( this );
     d->tmplabel->setText( KJavaAppletServer::getAppletLabel() );
diff --git a/tdehtml/java/kjavaappletwidget.h b/tdehtml/java/kjavaappletwidget.h
index 4912af125..08719b1d5 100644
--- a/tdehtml/java/kjavaappletwidget.h
+++ b/tdehtml/java/kjavaappletwidget.h
@@ -113,7 +113,7 @@ private:
     KJavaAppletWidgetPrivate* d;
 
     KJavaApplet* m_applet;
-    KWinModule*  m_kwm;
+    TWinModule*  m_kwm;
     TQString      m_swallowTitle;
 
 };
diff --git a/tdeui/kdetrayproxy/kdetrayproxy.cpp b/tdeui/kdetrayproxy/kdetrayproxy.cpp
index 6791b4c38..0a8be33a3 100644
--- a/tdeui/kdetrayproxy/kdetrayproxy.cpp
+++ b/tdeui/kdetrayproxy/kdetrayproxy.cpp
@@ -39,7 +39,7 @@ KDETrayProxy::KDETrayProxy()
          it != module.windows().end();
          ++it )
         windowAdded( *it );
-    tdeApp->installX11EventFilter( this ); // XSelectInput( StructureNotifyMask ) on windows is done by KWinModule
+    tdeApp->installX11EventFilter( this ); // XSelectInput( StructureNotifyMask ) on windows is done by TWinModule
 //    kdDebug() << "Init done" << endl;
     }
 
diff --git a/tdeui/kdetrayproxy/kdetrayproxy.h b/tdeui/kdetrayproxy/kdetrayproxy.h
index 2231be9ab..80113fc16 100644
--- a/tdeui/kdetrayproxy/kdetrayproxy.h
+++ b/tdeui/kdetrayproxy/kdetrayproxy.h
@@ -41,7 +41,7 @@ class KDETrayProxy
         void withdrawWindow( Window w );
         static Atom makeSelectionAtom();
         TDESelectionWatcher selection;
-        KWinModule module;
+        TWinModule module;
         TQValueList< Window > pending_windows;
         TQValueList< Window > tray_windows;
         TQMap< Window, unsigned long > docked_windows;
diff --git a/tdeui/kpassivepopup.h b/tdeui/kpassivepopup.h
index bc1b9ed1c..1ac3a87e9 100644
--- a/tdeui/kpassivepopup.h
+++ b/tdeui/kpassivepopup.h
@@ -319,7 +319,7 @@ protected:
     /**
      * If no relative window (eg taskbar button, system tray window) is
      * available, use this rectangle (pass it to moveNear()).
-     * Basically KWinModule::workArea() with width and height set to 0
+     * Basically TWinModule::workArea() with width and height set to 0
      * so that moveNear uses the upper-left position.
      * @return The TQRect to be passed to moveNear() if no other is
      * available.
diff --git a/tdeui/krootpixmap.cpp b/tdeui/krootpixmap.cpp
index ac54511f4..6dce0367a 100644
--- a/tdeui/krootpixmap.cpp
+++ b/tdeui/krootpixmap.cpp
@@ -38,7 +38,7 @@ class KRootPixmapData
 public:
     TQWidget *toplevel;
 #ifdef TQ_WS_X11
-    KWinModule *twin;
+    TWinModule *twin;
 #endif
 };
 
@@ -72,7 +72,7 @@ void KRootPixmap::init()
 #ifdef TQ_WS_X11
     connect(m_pPixmap, TQ_SIGNAL(done(bool)), TQ_SLOT(slotDone(bool)));
 
-    d->twin = new KWinModule( this );
+    d->twin = new TWinModule( this );
     connect(d->twin, TQ_SIGNAL(windowChanged(WId, unsigned int)), TQ_SLOT(desktopChanged(WId, unsigned int)));
     connect(d->twin, TQ_SIGNAL(currentDesktopChanged(int)), TQ_SLOT(desktopChanged(int)));
 #endif
diff --git a/tdeui/ksystemtray.cpp b/tdeui/ksystemtray.cpp
index 192b378b5..8afb0fd46 100644
--- a/tdeui/ksystemtray.cpp
+++ b/tdeui/ksystemtray.cpp
@@ -256,7 +256,7 @@ void KSystemTray::activateOrHide()
         minimizeRestore( true );
     else
     {
-        KWinModule module;
+        TWinModule module;
         for( TQValueList< WId >::ConstIterator it = module.stackingOrder().fromLast();
              it != module.stackingOrder().end() && (*it) != pw->winId();
              --it )
diff --git a/tdeui/twindowlistmenu.cpp b/tdeui/twindowlistmenu.cpp
index 5c1f977bb..c08bc9bc9 100644
--- a/tdeui/twindowlistmenu.cpp
+++ b/tdeui/twindowlistmenu.cpp
@@ -85,7 +85,7 @@ int NameSortedInfoList::compareItems( TQPtrCollection::Item s1, TQPtrCollection:
 KWindowListMenu::KWindowListMenu(TQWidget *parent, const char *name)
   : TDEPopupMenu(parent, name)
 {
-    twin_module = new KWinModule(this);
+    twin_module = new TWinModule(this);
 
     connect(this, TQ_SIGNAL(activated(int)), TQ_SLOT(slotExec(int)));
 }
diff --git a/tdeui/twindowlistmenu.h b/tdeui/twindowlistmenu.h
index 0e7884e39..2131ba5df 100644
--- a/tdeui/twindowlistmenu.h
+++ b/tdeui/twindowlistmenu.h
@@ -30,7 +30,7 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 
 #ifdef TQ_WS_X11 // not yet available for non-X11
 
-class KWinModule;
+class TWinModule;
 class KWindowListMenuPrivate;
 
 class TDEUI_EXPORT KWindowListMenu : public TDEPopupMenu
@@ -57,7 +57,7 @@ protected slots:
     void slotCascadeWindows();
 
 private:
-    KWinModule*         twin_module;
+    TWinModule*         twin_module;
     TQMap<int,WId>       map;
 protected:
     virtual void virtual_hook( int id, void* data );
diff --git a/tdecore/tdestartupinfo.cpp b/tdecore/tdestartupinfo.cpp
index e34964c25..a2ea6c4a7 100644
--- a/tdecore/tdestartupinfo.cpp
+++ b/tdecore/tdestartupinfo.cpp
@@ -94,7 +94,7 @@ struct TDEStartupInfoPrivate
         // contains ASN's that had change: but no new: yet
         TQMap< TDEStartupInfoId, TDEStartupInfo::Data > uninited_startups;
 #ifdef TQ_WS_X11
-        KWinModule* wm_module;
+        TWinModule* wm_module;
         KXMessages msgs;
 #endif
 	TQTimer* cleanup;
@@ -131,9 +131,9 @@ void TDEStartupInfo::init( int flags_P )
 
     d = new TDEStartupInfoPrivate( flags_P );
 #ifdef TQ_WS_X11
-    if( !( d->flags & DisableKWinModule ))
+    if( !( d->flags & DisableTWinModule ))
         {
-        d->wm_module = new KWinModule( this );
+        d->wm_module = new TWinModule( this );
         connect( d->wm_module, TQ_SIGNAL( windowAdded( WId )), TQ_SLOT( slot_window_added( WId )));
         connect( d->wm_module, TQ_SIGNAL( systemTrayWindowAdded( WId )), TQ_SLOT( slot_window_added( WId )));
         }
@@ -163,11 +163,11 @@ void TDEStartupInfo::got_message( const TQString& msg_P )
         got_remove_startup_info( msg.mid( 7 ));
     }
 
-// if the application stops responding for a while, KWinModule may get
+// if the application stops responding for a while, TWinModule may get
 // the information about the already mapped window before KXMessages
 // actually gets the info about the started application (depends
 // on their order in X11 event filter in TDEApplication)
 // simply delay info from KWinModule a bit
 // SELI???
 namespace
 {
@@ -163,11 +163,11 @@ void TDEStartupInfo::got_message( const TQString& msg_P )
 // actually gets the info about the started application (depends
 // on their order in X11 event filter in TDEApplication)
-// simply delay info from KWinModule a bit
+// simply delay info from TWinModule a bit
 // SELI???
 namespace
diff --git a/tdecore/tdestartupinfo.h b/tdecore/tdestartupinfo.h
index bf507c026..8df8ea182 100644
--- a/tdecore/tdestartupinfo.h
+++ b/tdecore/tdestartupinfo.h
@@ -125,7 +125,7 @@ class TDECORE_EXPORT TDEStartupInfo
 	 */
 	enum {
 	    CleanOnCantDetect		= 1 << 0,
-	    DisableKWinModule		= 1 << 1,
+	    DisableTWinModule		= 1 << 1,
 	    AnnounceSilenceChanges	= 1 << 2
 	    };
 	
@@ -135,7 +135,7 @@ class TDECORE_EXPORT TDEStartupInfo
 	 * @li CleanOnCantDetect - when a new unknown window appears, all startup
 	 *     notifications for applications that are not compliant with
 	 *     the startup protocol are removed
 	 * @li DisableKWinModule - KWinModule, which is normally used to detect
 	 *     new windows, is disabled. With this flag, checkStartup() must be
 	 *     called in order to check newly mapped windows.
 	 * @li AnnounceSilenceChanges - normally, startup notifications are
@@ -135,7 +135,7 @@ class TDECORE_EXPORT TDEStartupInfo
 	 *     notifications for applications that are not compliant with
 	 *     the startup protocol are removed
-	 * @li DisableKWinModule - KWinModule, which is normally used to detect
+	 * @li DisableTWinModule - TWinModule, which is normally used to detect
 	 *     new windows, is disabled. With this flag, checkStartup() must be
 	 *     called in order to check newly mapped windows.
diff --git a/tdecore/twinmodule.h b/tdecore/twinmodule.h
index 356e85958..fe09e5c5f 100644
--- a/tdecore/twinmodule.h
+++ b/tdecore/twinmodule.h
@@ -1,27 +1,27 @@
-/* This file is part of the KDE libraries
-    Copyright (C) 1999 Matthias Ettrich (ettrich@kde.org)
-
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+/* This file is part of the TDE libraries
+   Copyright (C) 1999 Matthias Ettrich (ettrich@kde.org)
+
+   This library is free software; you can redistribute it and/or
+   modify it under the terms of the GNU Library General Public
+   License as published by the Free Software Foundation; either
+   version 2 of the License, or (at your option) any later version.
+
+   This library is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+   Library General Public License for more details.
+
+   You should have received a copy of the GNU Library General Public License
+   along with this library; see the file COPYING.LIB.  If not, write to
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+   Boston, MA 02110-1301, USA.
 */
 /*
- * twinmodule.h. Part of the KDE project.
+ * twinmodule.h. Part of the TDE project.
  */
 
-#ifndef KWINMODULE_H
-#define KWINMODULE_H
+#ifndef TWINMODULE_H
+#define TWINMODULE_H
 
 #include <tqobject.h>
 #include <tqvaluelist.h>
@@ -29,27 +29,26 @@
 
 #ifdef Q_OS_UNIX
 
-class KWinModulePrivate;
+class TWinModulePrivate;
 
 /**
  *
  * The class KWinModule provides information about the state of the
  * window manager as required by windowmanager modules. It informs a
  * module about all currently managed windows and changes to them (via
- * Qt signals).
+ * TQt signals).
  *
  * KWinModule uses NETRootInfo internally. Modules written with this
  * class will work fine under any window manager that implements the
  * NET_WM protocol.
  *
  * There are no methods to manipulate windows. Those are defined in
  * the classes KWin, NETWinInfo and NETRootInfo.
  *
- *
- * @short Base class for KDE Window Manager modules.
+ * @short Base class for TDE Window Manager modules.
  * @author Matthias Ettrich (ettrich@kde.org)
  */
-class TDECORE_EXPORT KWinModule : public TQObject
+class TDECORE_EXPORT TWinModule : public TQObject
 {
     TQ_OBJECT
 
@@ -59,7 +58,7 @@ public:
            INFO_WINDOWS=2,
            INFO_ALL=32767 };
     /**
      * Creates a KWinModule object and connects to the window
      * manager.
      * @param parent the parent for the TQObject
      * @param what The information you are interested in:
@@ -85,23 +84,23 @@ public:
      *                  strutChanged,
      *                  workArea(const TQValueList<WId> &excludes, int desktop)
      **/
-    KWinModule( TQObject* parent, int what );
+    TWinModule( TQObject* parent, int what );
     /**
      * Creates a KWinModule object and connects to the window
      * manager.
      * @param parent the parent for the TQObject
      **/
-    KWinModule( TQObject* parent = 0 );
+    TWinModule( TQObject* parent = 0 );
 
     /**
      * Destructor. Internal cleanup, nothing fancy.
      **/
-    ~KWinModule();
+    ~TWinModule();
 
     /**
      * Returns the list of all toplevel windows currently managed by the
      * window manager in the order of creation. Please do not rely on
-     * indexes of this list: Whenever you enter Qt's event loop in your
+     * indexes of this list: Whenever you enter TQt's event loop in your
      * application, it may happen that entries are removed or added.
      * Your module should perhaps work on a copy of this list and verify a
      * window with hasWId() before any operations.
@@ -348,11 +347,14 @@ protected:
 private:
     void init(int);
 
-    KWinModulePrivate* d;
+    TWinModulePrivate* d;
 
-    friend class KWinModulePrivate;
+    friend class TWinModulePrivate;
 };
 
+// Temporary, until complete renaming is performed across all TDE code
+#define KWinModule TWinModule
+
 #endif //Q_OS_UNIX
 
 #endif
@@ -29,27 +29,26 @@
 /**
  *
- * The class KWinModule provides information about the state of the
+ * The class TWinModule provides information about the state of the
  * window manager as required by windowmanager modules. It informs a
  * module about all currently managed windows and changes to them (via
@@ -29,27 +29,26 @@
  *
- * KWinModule uses NETRootInfo internally. Modules written with this
+ * TWinModule uses NETRootInfo internally. Modules written with this
  * class will work fine under any window manager that implements the
  * NET_WM protocol.
@@ -59,7 +58,7 @@ public:
            INFO_ALL=32767 };
     /**
-     * Creates a KWinModule object and connects to the window
+     * Creates a TWinModule object and connects to the window
      * manager.
      * @param parent the parent for the TQObject
@@ -85,23 +84,23 @@ public:
     /**
-     * Creates a KWinModule object and connects to the window
+     * Creates a TWinModule object and connects to the window
      * manager.
      * @param parent the parent for the TQObject
-- 
cgit v1.2.3

